==> django-froala-editor-1.2.3.2.tar.gz: django-froala-editor-1.2.3.2/froala_editor/static/froala_editor/js/langs/pt_pt.js <==
/*!
 * froala_editor v1.2.3 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Portuguese spoken in Portugal
 */

$.Editable.LANGS['pt_pt'] = {
  translation: {
    "Bold": "Negrito",
    "Italic": "It\u00e1lico",
    "Underline": "Sublinhado",
    "Strikethrough": "Rasurado",
    "Font Size": "Tamanho da fonte",
    "Color": "Cor",
    "Background": "Fundo",
    "Text": "Texto",
    "Format Block": "Formatos",
    "Normal": "Normal",
    "Paragraph": "Par\u00e1grafo",
    "Code": "C\u00f3digo",
    "Quote": "Cita\u00e7\u00e3o",
    "Heading 1": "Cabe\u00e7alho 1",
    "Heading 2": "Cabe\u00e7alho 2",
    "Heading 3": "Cabe\u00e7alho 3",
    "Heading 4": "Cabe\u00e7alho 4",
    "Heading 5": "Cabe\u00e7alho 5",
    "Heading 6": "Cabe\u00e7alho 6",
    "Block Style": "Estilo do bloco",
    "Alignment": "Alinhamento",
    "Align Left": "Alinhar \u00e0 esquerda",
    "Align Center": "Alinhar ao centro",
    "Align Right": "Alinhar \u00e0 direita",
    "Justify": "Justificado",
    "Numbered List": "Lista numerada",
    "Bulleted List": "Lista com marcadores",
    "Indent Less": "Diminuir avan\u00e7o",
    "Indent More": "Aumentar avan\u00e7o",
    "Select All": "Seleccionar tudo",
    "Insert Link": "Inserir link",
    "Insert Image": "Inserir imagem",
    "Insert Video": "Inserir v\u00eddeo",
    "Undo": "Anular",
    "Redo": "Restaurar",
    "Show HTML": "Mostrar HTML",
    "Float Left": "Esquerda",
    "Float None": "Nenhum",
    "Float Right": "Direita",
    "Replace Image": "Substituir imagem",
    "Remove Image": "Remover imagem",
    "Title": "T\u00edtulo",
    "Drop image": "Largue imagem",
    "or click": "ou clique em",
    "or": "ou",
    "Enter URL": "Digite a URL",
    "Please wait!": "Por favor, sagacidade!",
    "Are you sure? Image will be deleted.": "Voc\u00ea tem certeza? Imagem ser\u00e1 apagada.",
    "UNLINK": "Remover link",
    "Open in new tab": "Abrir em uma nova aba",
    "Type something": "Digite algo",
    "Cancel": "Cancelar",
    "OK": "Ok",
    "Manage images": "Gerenciar as imagens",
    "Delete": "Apagar",
    "Font Family": "Fonte",
    "Insert Horizontal Line": "Inserir linha horizontal",
    "Table": "Tabela",
    "Insert table": "Inserir tabela",
    "Cell": "C\u00e9lula",
    "Row": "Linha",
    "Column": "Coluna",
    "Delete table": "Eliminar tabela",
    "Insert cell before": "Inserir c\u00e9lula antes",
    "Insert cell after": "Inserir c\u00e9lula depois",
    "Delete cell": "Excluir celular",
    "Merge cells": "Unir c\u00e9lulas",
    "Horizontal split": "Divis\u00e3o horizontal",
    "Vertical split": "Divis\u00e3o vertical",
    "Insert row above": "Inserir linha antes",
    "Insert row below": "Inserir linha depois",
    "Delete row": "Eliminar linha",
    "Insert column before": "Inserir coluna antes",
    "Insert column after": "Inserir coluna depois",
    "Delete column": "Eliminar coluna"
  },
  direction: "ltr"
};

==> django-froala-editor-1.2.4.2.tar.gz: django-froala-editor-1.2.4.2/froala_editor/static/froala_editor/js/langs/pt_pt.js <==
/*!
 * froala_editor v1.2.4 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Portuguese spoken in Portugal
 */

$.Editable.LANGS['pt_pt'] = {
  translation: {
    "Bold": "Negrito",
    "Italic": "It\u00e1lico",
    "Underline": "Sublinhado",
    "Strikethrough": "Rasurado",
    "Font Size": "Tamanho da fonte",
    "Color": "Cor",
    "Background": "Fundo",
    "Text": "Texto",
    "Format Block": "Formatos",
    "Normal": "Normal",
    "Paragraph": "Par\u00e1grafo",
    "Code": "C\u00f3digo",
    "Quote": "Cita\u00e7\u00e3o",
    "Heading 1": "Cabe\u00e7alho 1",
    "Heading 2": "Cabe\u00e7alho 2",
    "Heading 3": "Cabe\u00e7alho 3",
    "Heading 4": "Cabe\u00e7alho 4",
    "Heading 5": "Cabe\u00e7alho 5",
    "Heading 6": "Cabe\u00e7alho 6",
    "Block Style": "Estilo do bloco",
    "Alignment": "Alinhamento",
    "Align Left": "Alinhar \u00e0 esquerda",
    "Align Center": "Alinhar ao centro",
    "Align Right": "Alinhar \u00e0 direita",
    "Justify": "Justificado",
    "Numbered List": "Lista numerada",
    "Bulleted List": "Lista com marcadores",
    "Indent Less": "Diminuir avan\u00e7o",
    "Indent More": "Aumentar avan\u00e7o",
    "Select All": "Seleccionar tudo",
    "Insert Link": "Inserir link",
    "Insert Image": "Inserir imagem",
    "Insert Video": "Inserir v\u00eddeo",
    "Undo": "Anular",
    "Redo": "Restaurar",
    "Show HTML": "Mostrar HTML",
    "Float Left": "Esquerda",
    "Float None": "Nenhum",
    "Float Right": "Direita",
    "Replace Image": "Substituir imagem",
    "Remove Image": "Remover imagem",
    "Title": "T\u00edtulo",
    "Drop image": "Largue imagem",
    "or click": "ou clique em",
    "or": "ou",
    "Enter URL": "Digite a URL",
    "Please wait!": "Por favor, sagacidade!",
    "Are you sure? Image will be deleted.": "Voc\u00ea tem certeza? Imagem ser\u00e1 apagada.",
    "UNLINK": "Remover link",
    "Open in new tab": "Abrir em uma nova aba",
    "Type something": "Digite algo",
    "Cancel": "Cancelar",
    "OK": "Ok",
    "Manage images": "Gerenciar as imagens",
    "Delete": "Apagar",
    "Font Family": "Fonte",
    "Insert Horizontal Line": "Inserir linha horizontal",
    "Table": "Tabela",
    "Insert table": "Inserir tabela",
    "Cell": "C\u00e9lula",
    "Row": "Linha",
    "Column": "Coluna",
    "Delete table": "Eliminar tabela",
    "Insert cell before": "Inserir c\u00e9lula antes",
    "Insert cell after": "Inserir c\u00e9lula depois",
    "Delete cell": "Excluir celular",
    "Merge cells": "Unir c\u00e9lulas",
    "Horizontal split": "Divis\u00e3o horizontal",
    "Vertical split": "Divis\u00e3o vertical",
    "Insert row above": "Inserir linha antes",
    "Insert row below": "Inserir linha depois",
    "Delete row": "Eliminar linha",
    "Insert column before": "Inserir coluna antes",
    "Insert column after": "Inserir coluna depois",
    "Delete column": "Eliminar coluna",
    "Uploading image": "Upload de imagens",
    "Upload File": "Upload de arquivo",
    "Drop File": "Largar arquivo",
    "Clear formatting": "Remover formata\u00e7\u00e3o"
  },
  direction: "ltr"
};
